"""Top-level package for pybet365."""
from .client import (
    Bet365,
    Bet365SportId
)

__author__ = """Leon Kozlowski"""
__email__ = 'leonkozlowski@gmail.com'
__version__ = '0.1.1'

__all__ = [
    "Bet365",
    "Bet365SportId"
]
